# -*- coding: UTF-8 -*-
from mod.client.clientEvent import ClientEvent
from mod.client.system.clientSystem import ClientSystem
import mod.client.extraClientApi as clientApi


class Main(ClientSystem):

    def __init__(self, namespace, system_name):
        ClientSystem.__init__(self, namespace, system_name)
        namespace = clientApi.GetEngineNamespace()
        system_name = clientApi.GetEngineSystemName()
        # 监听UiInitFinished事件，从这里开始，之后都可以安全的创建界面
        self.ListenForEvent(namespace, system_name, ClientEvent.UiInitFinished, self, self.ui_init)
        self.ListenForEvent(namespace, system_name, 'AddEntityClientEvent', self, self.entity_added)
        self.ListenForEvent(namespace, system_name, 'RemoveEntityClientEvent', self, self.entity_remove)
        self.uis = []
        self.ui_inited = False

    def ui_init(self, event):
        # UI系统加载完毕
        self.ui_inited = True
        # 注册UI
        clientApi.RegisterUI('CustomUi', 'custom_ui',
                             'UiScripts.CustomUi.Main',
                             'custom_ui.main')
        clientApi.RegisterUI('CustomUi', 'custom_healthbar',
                             'UiScripts.CustomHealthBar.Main',
                             'custom_healthbar.main')
        # 创建滚动弹幕UI
        # clientApi.PushScreen('CustomUi', 'custom_ui')

    def entity_added(self, event):
        entity_id = event['id']
        if not self.ui_inited:
            return
        ui = clientApi.CreateUI('CustomUi', 'custom_healthbar', {
            'inputMode': 0,
            "bindEntityId": entity_id,
            "bindOffset": (0, 2, 0),
            "autoScale": 1
        })
        self.uis.append(ui)

    def entity_remove(self, event):
        entity_id = event['id']
        if not self.ui_inited:
            return
        ui_data = [(ui, ui.GetBindEntityId()) for ui in self.uis]
        i = -1
        for index, data in enumerate(ui_data):
            ui = data[0]
            ui_entity_id = data[1]
            if ui_entity_id == entity_id:
                ui.SetRemove()
                i = index
                break
        if i != -1:
            del self.uis[i]